==> statham-schema-0.4.0.tar.gz: statham-schema-0.4.0/statham/dsl/validation/format.py <==
from typing import Callable, Dict
from uuid import UUID
import warnings

from dateutil.parser import parse as parse_datetime, ParserError  # type: ignore


class _FormatString:
    """Extendable format string register.

    # TODO: Built-in formats.
    """

    def __init__(self, name: str):
        self._callable_register: Dict[str, Callable[[str], bool]] = {}
        self.__name__: str = name

    def register(self, format_string: str) -> Callable:
        def _register_callable(is_format: Callable[[str], bool]):
            self._callable_register[format_string] = is_format

        return _register_callable

    def __call__(self, format_string: str, value: str) -> bool:
        if format_string not in self._callable_register:
            full_name = f"{self.__module__}.{self.__name__}"
            warnings.warn(
                (
                    f"""No validator found for format string {format_string}.
To register new formats, please register a checker with
{full_name} as follows:\n
```\n
@{self.__name__}({format_string})\n
def is_{format_string.replace('-', '_')}value) -> bool:\n
    ...\n
```
"""
                ),
                RuntimeWarning,
            )
            return True
        return self._callable_register[format_string](value)


format_checker: _FormatString = _FormatString("format_checker")


@format_checker.register("uuid")
def _is_uuid(value: str) -> bool:
    try:
        UUID(value)
    except (ValueError, TypeError):
        return False
    return True


@format_checker.register("date-time")
def _is_date_time(value: str) -> bool:
    try:
        parse_datetime(value)
    except (ParserError, TypeError):
        return False
    return True

==> statham-schema-0.8.0.tar.gz: statham-schema-0.8.0/statham/dsl/validation/format.py <==
from typing import Callable, Dict
from uuid import UUID
import warnings

from dateutil.parser import parse as parse_datetime, ParserError  # type: ignore


class _FormatString:
    """Extendable format string register.

    # TODO: Built-in formats.
    """

    def __init__(self, name: str):
        self._callable_register: Dict[str, Callable[[str], bool]] = {}
        self.__name__: str = name

    def register(self, format_string: str) -> Callable:
        def _register_callable(is_format: Callable[[str], bool]):
            self._callable_register[format_string] = is_format

        return _register_callable

    def __call__(self, format_string: str, value: str) -> bool:
        if format_string not in self._callable_register:
            full_name = f"{self.__module__}.{self.__name__}"
            warnings.warn(
                (
                    f"""No validator found for format string {format_string}.
To register new formats, please register a checker with
{full_name} as follows:
```
@{self.__name__}({format_string})
def is_{format_string.replace('-', '_')}(value) -> bool:
    ...
```
"""
                ),
                RuntimeWarning,
            )
            return True
        return self._callable_register[format_string](value)


format_checker: _FormatString = _FormatString("format_checker")


@format_checker.register("uuid")
def _is_uuid(value: str) -> bool:
    try:
        UUID(value)
    except (ValueError, TypeError):
        return False
    return True


@format_checker.register("date-time")
def _is_date_time(value: str) -> bool:
    try:
        parse_datetime(value)
    except (ParserError, TypeError):
        return False
    return True
